@@ -750,7 +750,7 @@ MODULE_ENTRY (fill_info) (GdkPixbufFormat *info)
 
 	info->name = "pcx";
 	info->signature = (GdkPixbufModulePattern *) signature;
-	info->description = N_("The PCX image format");
+	info->description = NC_("image format", "PCX");
 	info->mime_types = (gchar **) mime_types;
 	info->extensions = (gchar **) extensions;
 	info->flags = GDK_PIXBUF_FORMAT_THREADSAFE;
