@@ -539,7 +539,7 @@ MODULE_ENTRY (fill_info) (GdkPixbufFormat *info)
 
 	info->name = "ras";
 	info->signature = (GdkPixbufModulePattern *) signature;
-	info->description = N_("The Sun raster image format");
+	info->description = NC_("image format", "Sun raster");
 	info->mime_types = (gchar **) mime_types;
 	info->extensions = (gchar **) extensions;
 	info->flags = GDK_PIXBUF_FORMAT_THREADSAFE;
